<template>
  <div>
    <ttable
      :table="table"
      :uploadInfo="{
        isShow: false
      }"
      :paramObj="{
        queryType: 1
      }"
      :options="options"
      :ajaxFun="ajaxFun"
      :bottomOffset="80"
      ref="reportTableNewTab2"
      @currentChange="currentChange"
    >
      <template #toolbar />
    </ttable>
  </div>
</template>

<script>
import {
  fetchList,
  putReportSubmit,
  putReportCancelSubmit,
  delReport
} from '@/api/quality/newReport'
import { remote } from '@/api/admin/dict'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'

export default {
  data() {
    const tt = (prop, label, config) => {
      const w = (label.length - 1) * 20 + 15
      return Object.assign(
        {
          minWidth: w,
          width: w < 110 ? 110 : w,
          prop,
          label,
          sort: true,
          isTrue: true,
          isSearch: true,
          searchInfoType: 'text'
        },
        config
      )
    }
    return {
      ajaxFun: fetchList,
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'reportNo', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          tt('reportState', '提交状态', {
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              return cellValue.replace('汇报', '')
            },
            optList: () => {
              return [
                { label: '已提交', value: '汇报已提交' },
                { label: '未提交', value: '汇报未提交' }
              ]
            }
          }),
          tt('applyNo', '申请编号'),
          tt('reportNo', '汇报编号', {
            render: { fun: this.goEdit }
          }),
          tt('applyType', '汇报类型', {
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              const i = this.applyTypeList.find((e) => e.value === cellValue)
              return i ? i.label : ''
            },
            optList: () => {
              return this.applyTypeList
            }
          }),
          tt('moNo', '车间订单号'),
          tt('systemNo', '系统号'),
          tt('reelNumber', '载具编号'),
          tt('outBatchNo', 'SN号'),
          tt('partNo', '零件号'),
          tt('partName', '零件名称'),
          tt('replacePartNo', '替代零件号'),
          tt('checkLength', '入库长度'),
          tt('totalLength', '报检长度'),
          tt('scrapArrived', '报废长度'),
          tt('operationName', '工序'),
          tt('workstationName', '机台'),
          tt('reportPerson', '检测人员'),
          tt('checkTime', '检测时间', {
            searchInfoType: 'datetimerange'
          }),
          tt('produceUser', '生产人员'),
          tt('applyUser', '报检人员')
        ],
        toolbar: [
          {
            text: '提交',
            type: 'primary',
            fun: this.goSubmit,
            disabled: true
          },
          {
            text: '撤回',
            type: 'primary',
            fun: this.goRevert,
            disabled: true
          },
          {
            text: '删除',
            type: 'primary',
            fun: this.goDel,
            disabled: true
          }
        ]
      },
      applyTypeList: [],
      currentRow: null,
      visible: {
        库位: false
      }
    }
  },
  components: {
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {
    remote('apply_report_type').then((response) => {
      if (response.data.code === 0) {
        this.applyTypeList = response.data.data
      } else {
        this.applyTypeList = []
      }
    })
  },

  activated() {},
  methods: {
    // 获取数据列表
    getData() {
      return this.$refs.reportTableNewTab2.getDataList()
    },
    currentChange(row) {
      this.currentRow = row
      this.table.toolbar.forEach((e) => (e.disabled = true))
      if (row) {
        if (row.reportState === '汇报未提交') {
          this.table.toolbar[0].disabled = false
          this.table.toolbar[2].disabled = false
        } else {
          this.table.toolbar[1].disabled = false
        }
      }
    },
    goEdit(row) {
      sessionStorage.setItem('ztt-newReportRow', JSON.stringify(row))
      this.$router.push({
        name: 'newReportForm',
        query: {
          type: 'edit'
        }
      })
    },
    goSubmit() {
      putReportSubmit({}, this.currentRow.reportId).then((response) => {
        const resData = response.data
        if (resData.code === 0) {
          this.getData()
          this.$message.success('检测汇报提交成功！')
        } else {
          this.$message.error('检测汇报提交失败！')
        }
      })
    },
    goRevert() {
      putReportCancelSubmit({}, this.currentRow.reportId).then((response) => {
        const resData = response.data
        if (resData.code === 0) {
          this.getData()
          this.$message.success('检测汇报撤销成功！')
        } else {
          this.$message.error('检测汇报撤销失败！')
        }
      })
    },
    goDel() {
      this.$confirm(
        '是否确认删除汇报编号为：' + this.currentRow.reportNo,
        '提示',
        {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal: false,
          type: 'warning'
        }
      )
        .then(() => {
          return delReport(this.currentRow.reportId)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
